package com.bjsxt.dao.impl;

import com.bjsxt.commons.JdbcUtils;
import com.bjsxt.dao.UserManagerDao;
import com.bjsxt.pojo.Users;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

/**
 * 用户管理持久层
 */
public class UserManagerDaoImpl implements UserManagerDao {
    @Override
    public void insertUser(Users users) {
        Connection conn = null;
        try {
            //为了加深对事物的理解，练习  先将自动提交关闭，换成手动提交
            //先取conn  再关闭自动提交
            conn = JdbcUtils.getConnection();
            conn.setAutoCommit(false);
            //再手动提交
            PreparedStatement ps= conn.prepareStatement("insert into users values(default,?,?,?,?,?)");
            //绑定参数
            ps.setString(1,users.getUsername());
            ps.setString(2,users.getUserpwd());
            ps.setString(3,users.getUsersex());
            ps.setString(4,users.getPhonenumber());
            ps.setString(5,users.getQqnumber());
            //执行SQL语句
            ps.execute();
            //事物提交
            conn.commit();
        }catch (Exception e){
            e.printStackTrace();
            //事物提交如果出现异常了,rollback 事务回滚会抛出异常，可放到JdbcUtils
            //conn.rollback();
            JdbcUtils.rollbackConnection(conn);
        }finally {
            //关闭连接
            JdbcUtils.closeConnection(conn);
        }
    }

    /**
     * 查询用户
     * @param users
     * @return
     */
    @Override
    public List<Users> selectUserByProperty(Users users) {
        //定义
        Connection conn = null;
        //创建一个List
        List<Users> list = new ArrayList<>();
        try {
            conn=JdbcUtils.getConnection();
            //定义一个方法专门做SQL语句的拼接
            String sql = this.createSQL(users);
            PreparedStatement preparedStatement=conn.prepareStatement(sql);
            ResultSet resultSet = preparedStatement.executeQuery();
            while (resultSet.next()){
                Users user = new Users();
                user.setUserid(resultSet.getInt("userid"));
                user.setPhonenumber(resultSet.getString("phonenumber"));
                user.setQqnumber(resultSet.getString("qqnumber"));
                user.setUserpwd(resultSet.getString("userpwd"));
                user.setUsername(resultSet.getString("username"));
                user.setUsersex(resultSet.getString("usersex"));
                list.add(user);
            }
        }catch (Exception e){
            e.printStackTrace();
        }finally {
            JdbcUtils.closeConnection(conn);
        }
        return null;
    }
    //拼接查询的SQL语句
    private String createSQL(Users users){
        StringBuffer stringBuffer = new StringBuffer("select * from users where 1=1 ");  //查询所有
        if(users.getUsersex() != null && users.getUsersex().length() > 0){
            //说明users.getUsersex()中是有值的将它拼接到stringBuffer的SQL语句中
            stringBuffer.append(" and usersex= "+users.getUsersex());
        }
        if(users.getQqnumber() != null&& users.getQqnumber().length() >0){
            stringBuffer.append(" and qqnumber= "+users.getQqnumber());
        }
        if(users.getUsername() != null && users.getUsername().length() >0){
            stringBuffer.append(" and username= "+users.getUsername());
        }
        if(users.getPhonenumber() !=null && users.getPhonenumber().length() >0){
            stringBuffer.append(" and phonenumber "+users.getPhonenumber());
        }
        return stringBuffer.toString();
    }
}
