package com.bjsxt.web.servlet;

import com.bjsxt.commons.Constants;
import com.bjsxt.exception.UserNotFoundException;
import com.bjsxt.pojo.Users;
import com.bjsxt.service.UserLoginService;
import com.bjsxt.service.impl.UserLoginServiceImpl;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;

/**
 * 处理用户登录请求
 */
@WebServlet("/login.do")
public class UserLoginServlet extends HttpServlet {
    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        this.doPost(req, resp);
    }

    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        //处理用户登录的请求
        //获取表单中的内容(用户输入的)
        String username=req.getParameter("username");
        String userpwd=req.getParameter("userpwd");
        String code=req.getParameter("code");   //获取验证码
        //创建业务层对象，调用所对应的用户登录方法
        //如果查不到用户，会出现一个异常，try-catch就是用来处理这个异常的
        try {
            //建立客户端与服务端的会话状态
            HttpSession session = req.getSession();   //先获取session
            //从session中获取到的验证码
            String codeTemp=(String)session.getAttribute(Constants.VALIDATE_CODE_KEY);
            if(codeTemp.equals(code)){
                //创建业务层对象
                UserLoginService userLoginService = new UserLoginServiceImpl();
                //调用业务层方法  返回一个users
                Users users = userLoginService.UserLogin(username, userpwd);

                session.setAttribute(Constants.USER_SESSION_KEY,users);  //把查到的用户放到session中
                //获取servletContext对象  用于设置只在一处登录
                ServletContext servletContext = this.getServletContext();
                //从servletContext对象中获取用户id所对应的session  返回的是object类型，强转为HttpSession
                HttpSession temp = (HttpSession)servletContext.getAttribute(users.getUserid()+"");
                //判断用户是否已登录
                if (temp != null){
                    //先从servletContext对象中把这个数据删除掉，再把取出来的session销毁
                    servletContext.removeAttribute(users.getUserid()+"");
                    temp.invalidate();
                }
                //再将新使用的session和userid放到servletContext对象中
                servletContext.setAttribute(users.getUserid()+"",session);
                //使用重定向方式跳转首页  因为重定向可以改变地址栏的URL
                resp.sendRedirect("main.jsp");  //里面是跳转的jsp页面
            }else{
                //输出提示信息，并请求转发，跳转到Login.jsp
                req.setAttribute(Constants.REQUEST_MSG,"验证码输入错误，请重新输入！");
                req.getRequestDispatcher("login.jsp").forward(req,resp);
            }

            //用户登陆成功跳转首页，登录不成功会跳转到login.jsp，提示一个信息
        }catch (UserNotFoundException e){
            //e.printStackTrace();
            //取信息 从UserNotFoundException中取到的值
            req.setAttribute("msg",e.getMessage());
            //将取出来的值传到login.jsp页面中 用请求转发 跳转
            req.getRequestDispatcher("login.jsp").forward(req,resp);
        }catch (Exception e){
            e.printStackTrace();
            resp.sendRedirect("error.jsp");
        }

    }
}
